<?php

namespace Litecms\RegisterSettings\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\RegisterSettings\Http\Requests\RegisterationFieldRequest;
use Litecms\RegisterSettings\Interfaces\RegisterationFieldRepositoryInterface;
use Litecms\RegisterSettings\Models\RegisterationField;

/**
 * Resource controller class for registeration_field.
 */
class RegisterationFieldResourceController extends BaseController
{

    /**
     * Initialize registeration_field resource controller.
     *
     * @param type RegisterationFieldRepositoryInterface $registeration_field
     *
     * @return null
     */
    public function __construct(RegisterationFieldRepositoryInterface $registeration_field)
    {
        parent::__construct();
        $this->repository = $registeration_field;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\RegisterSettings\Repositories\Criteria\RegisterationFieldResourceCriteria::class);
    }

    /**
     * Display a list of registeration_field.
     *
     * @return Response
     */
    public function index(RegisterationFieldRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\RegisterSettings\Repositories\Presenter\RegisterationFieldPresenter::class)
                ->$function();
        }

        $registeration_fields = $this->repository->paginate();

        return $this->response->title(trans('register_settings::registeration_field.names'))
            ->view('register_settings::registeration_field.index', true)
            ->data(compact('registeration_fields'))
            ->output();
    }

    /**
     * Display registeration_field.
     *
     * @param Request $request
     * @param Model   $registeration_field
     *
     * @return Response
     */
    public function show(RegisterationFieldRequest $request, RegisterationField $registeration_field)
    {

        if ($registeration_field->exists) {
            $view = 'register_settings::registeration_field.show';
        } else {
            $view = 'register_settings::registeration_field.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('register_settings::registeration_field.name'))
            ->data(compact('registeration_field'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new registeration_field.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(RegisterationFieldRequest $request)
    {

        $registeration_field = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('register_settings::registeration_field.name')) 
            ->view('register_settings::registeration_field.create', true) 
            ->data(compact('registeration_field'))
            ->output();
    }

    /**
     * Create new registeration_field.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(RegisterationFieldRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $registeration_field                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('register_settings::registeration_field.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('register_settings/registeration_field/' . $registeration_field->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/register_settings/registeration_field'))
                ->redirect();
        }

    }

    /**
     * Show registeration_field for editing.
     *
     * @param Request $request
     * @param Model   $registeration_field
     *
     * @return Response
     */
    public function edit(RegisterationFieldRequest $request, RegisterationField $registeration_field)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('register_settings::registeration_field.name'))
            ->view('register_settings::registeration_field.edit', true)
            ->data(compact('registeration_field'))
            ->output();
    }

    /**
     * Update the registeration_field.
     *
     * @param Request $request
     * @param Model   $registeration_field
     *
     * @return Response
     */
    public function update(RegisterationFieldRequest $request, RegisterationField $registeration_field)
    {
        try {
            $attributes = $request->all();

            $registeration_field->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('register_settings::registeration_field.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('register_settings/registeration_field/' . $registeration_field->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('register_settings/registeration_field/' . $registeration_field->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the registeration_field.
     *
     * @param Model   $registeration_field
     *
     * @return Response
     */
    public function destroy(RegisterationFieldRequest $request, RegisterationField $registeration_field)
    {
        try {

            $registeration_field->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('register_settings::registeration_field.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('register_settings/registeration_field/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('register_settings/registeration_field/' . $registeration_field->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple registeration_field.
     *
     * @param Model   $registeration_field
     *
     * @return Response
     */
    public function delete(RegisterationFieldRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('register_settings::registeration_field.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('register_settings/registeration_field'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/register_settings/registeration_field'))
                ->redirect();
        }

    }

    /**
     * Restore deleted registeration_fields.
     *
     * @param Model   $registeration_field
     *
     * @return Response
     */
    public function restore(RegisterationFieldRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('register_settings::registeration_field.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/register_settings/registeration_field'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/register_settings/registeration_field/'))
                ->redirect();
        }

    }

}
