<?php

namespace Litecms\RegisterSettings\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\RegisterSettings\Models\RegisterationField;

class RegisterationFieldPolicy
{

    /**
     * Determine if the given user can view the registeration_field.
     *
     * @param UserPolicy $user
     * @param RegisterationField $registeration_field
     *
     * @return bool
     */
    public function view(UserPolicy $user, RegisterationField $registeration_field)
    {
        if ($user->canDo('register_settings.registeration_field.view') && $user->isAdmin()) {
            return true;
        }

        return $registeration_field->user_id == user_id() && $registeration_field->user_type == user_type();
    }

    /**
     * Determine if the given user can create a registeration_field.
     *
     * @param UserPolicy $user
     * @param RegisterationField $registeration_field
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('register_settings.registeration_field.create');
    }

    /**
     * Determine if the given user can update the given registeration_field.
     *
     * @param UserPolicy $user
     * @param RegisterationField $registeration_field
     *
     * @return bool
     */
    public function update(UserPolicy $user, RegisterationField $registeration_field)
    {
        if ($user->canDo('register_settings.registeration_field.edit') && $user->isAdmin()) {
            return true;
        }

        return $registeration_field->user_id == user_id() && $registeration_field->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given registeration_field.
     *
     * @param UserPolicy $user
     * @param RegisterationField $registeration_field
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, RegisterationField $registeration_field)
    {
        return $registeration_field->user_id == user_id() && $registeration_field->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given registeration_field.
     *
     * @param UserPolicy $user
     * @param RegisterationField $registeration_field
     *
     * @return bool
     */
    public function verify(UserPolicy $user, RegisterationField $registeration_field)
    {
        if ($user->canDo('register_settings.registeration_field.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given registeration_field.
     *
     * @param UserPolicy $user
     * @param RegisterationField $registeration_field
     *
     * @return bool
     */
    public function approve(UserPolicy $user, RegisterationField $registeration_field)
    {
        if ($user->canDo('register_settings.registeration_field.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
