<?php

namespace Litecms\RegisterSettings\Providers;

use Illuminate\Support\ServiceProvider;

class RegisterSettingsServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'register_settings');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'register_settings');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.register_settings', function ($app) {
            return $this->app->make('Litecms\RegisterSettings\RegisterSettings');
        });

                // Bind RegisterationField to repository
        $this->app->bind(
            'Litecms\RegisterSettings\Interfaces\RegisterationFieldRepositoryInterface',
            \Litecms\RegisterSettings\Repositories\Eloquent\RegisterationFieldRepository::class
        );

        $this->app->register(\Litecms\RegisterSettings\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\RegisterSettings\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.register_settings'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/register_settings.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/register_settings')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/register_settings')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
